@@ -1,12 +1,12 @@
 
 __name__ = 'pyplasma'
 __author__ = 'Jean-Luc Déziel'
-__version__ = '0.3.1'
+__version__ = '0.3.2'
 
 from .backend import backend
 from .backend import set_backend
 
-from .simulation import Domain, Time
+from .simulation import Domain
 from .laser import Laser
 from .material import Material
 from .observers import *
